aboutsummaryrefslogtreecommitdiffstats
path: root/os/kernel/include/mutexes.h
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2010-02-06 12:31:09 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2010-02-06 12:31:09 +0000
commit8e428dbd1a48615c36c8c086dd51079050c9fb1c (patch)
treed1c7168826614acb1925e997915a010f3c4d999b /os/kernel/include/mutexes.h
parentf17db1931e95f5ebb42f557b6eead2bf1320db5a (diff)
downloadChibiOS-8e428dbd1a48615c36c8c086dd51079050c9fb1c.tar.gz
ChibiOS-8e428dbd1a48615c36c8c086dd51079050c9fb1c.tar.bz2
ChibiOS-8e428dbd1a48615c36c8c086dd51079050c9fb1c.zip
Kernel headers cleanup.
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@1568 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/kernel/include/mutexes.h')
-rw-r--r--os/kernel/include/mutexes.h30
1 files changed, 17 insertions, 13 deletions
diff --git a/os/kernel/include/mutexes.h b/os/kernel/include/mutexes.h
index 32fcc0f6b..5bdbcdbd9 100644
--- a/os/kernel/include/mutexes.h
+++ b/os/kernel/include/mutexes.h
@@ -18,8 +18,9 @@
*/
/**
- * @file mutexes.h
- * @brief Mutexes macros and structures.
+ * @file mutexes.h
+ * @brief Mutexes macros and structures.
+ *
* @addtogroup mutexes
* @{
*/
@@ -33,12 +34,12 @@
* @brief Mutex structure.
*/
typedef struct Mutex {
- ThreadsQueue m_queue; /**< Queue of the threads sleeping on
- this Mutex.*/
- Thread *m_owner; /**< Owner @p Thread pointer or
- @p NULL.*/
- struct Mutex *m_next; /**< Next @p Mutex into an owner-list
- or @p NULL.*/
+ ThreadsQueue m_queue; /**< @brief Queue of the threads sleeping
+ on this Mutex. */
+ Thread *m_owner; /**< @brief Owner @p Thread pointer or
+ @p NULL. */
+ struct Mutex *m_next; /**< @brief Next @p Mutex into an
+ owner-list or @p NULL. */
} Mutex;
#ifdef __cplusplus
@@ -57,23 +58,26 @@ extern "C" {
#endif
/**
- * @brief Data part of a static mutex initializer.
+ * @brief Data part of a static mutex initializer.
* @details This macro should be used when statically initializing a mutex
* that is part of a bigger structure.
- * @param name the name of the mutex variable
+ *
+ * @param[in] name the name of the mutex variable
*/
#define _MUTEX_DATA(name) {_THREADSQUEUE_DATA(name.m_queue), NULL, NULL}
/**
- * @brief Static mutex initializer.
+ * @brief Static mutex initializer.
* @details Statically initialized mutexes require no explicit initialization
* using @p chMtxInit().
- * @param name the name of the mutex variable
+ *
+ * @param[in] name the name of the mutex variable
*/
#define MUTEX_DECL(name) Mutex name = _MUTEX_DATA(name)
/**
* Returns @p TRUE if the mutex queue contains at least a waiting thread.
*/
#define chMtxQueueNotEmptyS(mp) notempty(&(mp)->m_queue)
@@ -57,23 +58,26 @@ extern "C" {
#define MUTEX_DECL(name) Mutex name = _MUTEX_DATA(name)
/**
- * Returns @p TRUE if the mutex queue contains at least a waiting thread.
+ * @brief Returns @p TRUE if the mutex queue contains at least a waiting
+ * thread.
*/
#define chMtxQueueNotEmptyS(mp) notempty(&(mp)->m_queue)